PREC=A
ENCUT=400
ISYM=0
ALGO=Fast
EDIFF=1.000000e-06
LREAL=False
NPAR=4
KPAR=1
NELM=120
NELMIN=4
ISIF=2
ISMEAR=0
SIGMA=0.20000
IBRION=0
POTIM=0.5
NSW=10
LWAVE=F
LCHARG=F
PSTRESS=0
KSPACING=0.500000
KGAMMA=.FALSE.
